@@ -1,4 +1,5 @@
-logproby <- function(y,XX,ZZ,aa,bb,s2,nu){
+logproby <-
+function(y,XX,ZZ,aa,bb,s2,nu){
   df=nu
   n=length(y)
   U=aa*ZZ+bb*XX+diag(n)
@@ -6,4 +7,3 @@ logproby <- function(y,XX,ZZ,aa,bb,s2,nu){
   log.prob=dmt(y,mean=rep(0,n),df=df,S=S,log=TRUE)
   log.prob
 }
-
