@@ -1,4 +1,5 @@
-matrix.inv.calculation=function(V){
+matrix.inv.calculation <-
+function(V){
     cV=chol(V)
     V.inv=chol2inv(cV)
     rm(cV)
