@@ -1,4 +1,5 @@
-matrix.invroot.calculation=function(V){
+matrix.invroot.calculation <-
+function(V){
     E=eigen(V)
     E.vector=E$vectors
     V.inv.root=E.vector%*%diag(1/sqrt(E$values))%*%t(E.vector)
